<?php

declare(strict_types=1);

namespace Paysera\Payment\Helper;

use Evp\Component\Money\Money;
use Paysera\CheckoutSdk\Entity\Order;
use Paysera\CheckoutSdk\Entity\PaymentCallbackValidationResponse;
use Paysera\CheckoutSdk\Service\PaymentStatus;

class PaymentHelper
{
    public function isMerchantOrderPaid(
        PaymentCallbackValidationResponse $callbackResponse,
        Order                             $merchantOrder
    ): bool {
        if ($callbackResponse->getStatus() !== PaymentStatus::SUCCESS) {
            return false;
        }

        $merchantAmount = new Money($merchantOrder->getAmount());
        $merchantCurrency = $merchantOrder->getCurrency();
        $callbackAmount = new Money($callbackResponse->getOrder()->getAmount());
        $callbackCurrency = $callbackResponse->getOrder()->getCurrency();
        $callbackPaymentAmount = new Money($callbackResponse->getPaymentAmount());
        $callbackPaymentCurrency = $callbackResponse->getPaymentCurrency();

        return ($merchantAmount->isEqual($callbackAmount) && $callbackCurrency === $merchantCurrency)
            || ($merchantAmount->isEqual($callbackPaymentAmount) && $callbackPaymentCurrency === $merchantCurrency);
    }
}
