<?php

declare(strict_types=1);

namespace Paysera\Payment\Model;

use Opencart\Catalog\Model\Checkout\Order as OpencartOrderModel;
use Paysera\Payment\Entity\Order;
use Paysera\Payment\Exception\OrderException;
use Paysera\Payment\Service\Helper\AmountHelper;
use Paysera\Payment\Normalizer\OrderNormalizer;
use Opencart\System\Engine\Proxy;
use Opencart\System\Library\Cart\Currency;

class OrderModel
{
    /**
     * ModelCheckoutOrder - catalog/model/checkout/order.php
     */
    private $orderModel;
    private OrderNormalizer $orderNormalizer;

    /**
     * @var Currency
     */
    private $currency;


    public function __construct(
        $orderModel,
        OrderNormalizer $orderNormalizer,
        $currency
    ) {
        $this->orderModel = $orderModel;
        $this->orderNormalizer = $orderNormalizer;
        $this->currency = $currency;
    }

    public function getOrder(int $orderId): ?Order
    {
        $orderAsArray = $this->orderModel->getOrder($orderId);

        if (!isset($orderAsArray['total'], $orderAsArray['currency_code'])) {
            throw new OrderException('Can not count order amount in cents. Necessary fields are absent.');
        }

        $orderAsArray['amount'] = (float) $orderAsArray['total'];
        $orderAsArray['amount'] *= $this->currency->getValue((string) $orderAsArray['currency_code']);

        return $this->orderNormalizer->mapToEntity($orderAsArray);
    }

    public function addHistory(int $orderId, int $orderStatusId): void
    {
        $this->orderModel->addHistory($orderId, $orderStatusId);
    }
}
